==> aTunes_1.9.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/controllers/navigation/RadioViewRefresher.java <==
/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.controllers.navigation;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;

import net.sourceforge.atunes.kernel.handlers.RadioHandler;
import net.sourceforge.atunes.kernel.modules.radio.Radio;
import net.sourceforge.atunes.utils.LanguageTool;

/**
 * The Class RadioViewRefresher.
 */
public class RadioViewRefresher {

	/**
	 * Adds the radio nodes.
	 * 
	 * @param radios
	 *            the radios
	 * @param presetRadios
	 *            the preset radios
	 * @param root
	 *            the root
	 * @param currentFilter
	 *            the current filter
	 * @param showAllStations
	 *            the show all stations
	 */
	private static void addRadioNodes(List<Radio> radios, List<Radio> presetRadios, DefaultMutableTreeNode root, String currentFilter, boolean showAllStations) {
		if (radios == null)
			return;

		// Group radios by label
		Map<String, DefaultMutableTreeNode> radioGroups = new HashMap<String, DefaultMutableTreeNode>();
		Map<String, DefaultMutableTreeNode> radioGroupNoLabel = new HashMap<String, DefaultMutableTreeNode>();

		for (Radio r : radios) {
			if (currentFilter == null || r.getName().toUpperCase().contains(currentFilter.toUpperCase())) {
				// Create radio node
				DefaultMutableTreeNode radioNode = new DefaultMutableTreeNode(r);

				// Insert radio node into label node; "REMOVED" tag means we should not display this station
				if (radioGroups.containsKey(r.getLabel()) && !r.isRemoved())
					radioGroups.get(r.getLabel()).add(radioNode);
				else if (r.isRemoved()) {
					if (!presetRadios.isEmpty())
						presetRadios.remove(r);
				} else {
					DefaultMutableTreeNode labelNode;
					if (r.getLabel() == null || r.getLabel().trim().equals("")) {
						//labelNode = new DefaultMutableTreeNode(LanguageTool.getString("UNLABELED"));
						radioGroupNoLabel.put(r.getName(), radioNode);
					} else {
						if (!r.isRemoved()) {
							labelNode = new DefaultMutableTreeNode(r.getLabel());
							labelNode.add(radioNode);
							radioGroups.put(r.getLabel(), labelNode);
						}
					}
				}
			}
		}

		if (presetRadios != null && showAllStations) {
			for (Radio r : presetRadios) {
				if (currentFilter == null || r.getName().toUpperCase().contains(currentFilter.toUpperCase())) {
					// Create radio node
					DefaultMutableTreeNode radioNode = new DefaultMutableTreeNode(r);

					// Insert radio node into label node
					if (radioGroups.containsKey(r.getLabel()) && !r.isRemoved()) {
						radioGroups.get(r.getLabel()).add(radioNode);
					}
					// Marked as removed, so remove for next start
					else if (r.isRemoved())
						RadioHandler.getInstance().removeRadio(r);
					else {
						DefaultMutableTreeNode labelNode;
						if (r.getLabel() == null || r.getLabel().trim().equals("")) {
							//labelNode = new DefaultMutableTreeNode(LanguageTool.getString("UNLABELED"));
							radioGroupNoLabel.put(r.getName(), radioNode);
						} else {
							if (!r.isRemoved()) {
								labelNode = new DefaultMutableTreeNode(r.getLabel());
								labelNode.add(radioNode);
								radioGroups.put(r.getLabel(), labelNode);
							}
						}
					}
				}
			}
		}

		// Add label nodes
		for (DefaultMutableTreeNode labelNode : radioGroups.values()) {
			root.add(labelNode);
		}
		// Add radio nodes without labels
		for (DefaultMutableTreeNode radioNode : radioGroupNoLabel.values()) {
			root.add(radioNode);
		}
	}

	/**
	 * Refresh.
	 * 
	 * @param radios
	 *            the radios
	 * @param presetRadios
	 *            the preset radios
	 * @param treeModel
	 *            the tree model
	 * @param currentFilter
	 *            the current filter
	 * @param showAllStations
	 *            the show all stations
	 */
	public static void refresh(List<Radio> radios, List<Radio> presetRadios, DefaultTreeModel treeModel, String currentFilter, boolean showAllStations) {
		DefaultMutableTreeNode root = (DefaultMutableTreeNode) treeModel.getRoot();
		root.setUserObject(LanguageTool.getString("RADIO"));
		root.removeAllChildren();
		addRadioNodes(radios, presetRadios, root, currentFilter, showAllStations);
		treeModel.reload();
	}
}

==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/controllers/navigation/RadioViewRefresher.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.controllers.navigation;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;

import net.sourceforge.atunes.kernel.handlers.RadioHandler;
import net.sourceforge.atunes.kernel.modules.radio.Radio;
import net.sourceforge.atunes.utils.LanguageTool;

/**
 * The Class RadioViewRefresher.
 */
public class RadioViewRefresher {

	/**
	 * Adds the radio nodes.
	 * 
	 * @param radios
	 *            the radios
	 * @param presetRadios
	 *            the preset radios
	 * @param root
	 *            the root
	 * @param currentFilter
	 *            the current filter
	 * @param showAllStations
	 *            the show all stations
	 */
	private static void addRadioNodes(List<Radio> radios, List<Radio> presetRadios, DefaultMutableTreeNode root, String currentFilter, boolean showAllStations) {
		if (radios == null) {
			return;
		}

		// Group radios by label
		Map<String, DefaultMutableTreeNode> radioGroups = new HashMap<String, DefaultMutableTreeNode>();
		Map<String, DefaultMutableTreeNode> radioGroupNoLabel = new HashMap<String, DefaultMutableTreeNode>();

		for (Radio r : radios) {
			if (currentFilter == null || r.getName().toUpperCase().contains(currentFilter.toUpperCase())) {
				// Create radio node
				DefaultMutableTreeNode radioNode = new DefaultMutableTreeNode(r);

				// Insert radio node into label node; "REMOVED" tag means we should not display this station
				if (radioGroups.containsKey(r.getLabel()) && !r.isRemoved()) {
					radioGroups.get(r.getLabel()).add(radioNode);
				} else if (r.isRemoved()) {
					if (!presetRadios.isEmpty()) {
						presetRadios.remove(r);
					}
				} else {
					DefaultMutableTreeNode labelNode;
					if (r.getLabel() == null || r.getLabel().trim().equals("")) {
						//labelNode = new DefaultMutableTreeNode(LanguageTool.getString("UNLABELED"));
						radioGroupNoLabel.put(r.getName(), radioNode);
					} else {
						if (!r.isRemoved()) {
							labelNode = new DefaultMutableTreeNode(r.getLabel());
							labelNode.add(radioNode);
							radioGroups.put(r.getLabel(), labelNode);
						}
					}
				}
			}
		}

		if (presetRadios != null && showAllStations) {
			for (Radio r : presetRadios) {
				if (currentFilter == null || r.getName().toUpperCase().contains(currentFilter.toUpperCase())) {
					// Create radio node
					DefaultMutableTreeNode radioNode = new DefaultMutableTreeNode(r);

					// Insert radio node into label node
					if (radioGroups.containsKey(r.getLabel()) && !r.isRemoved()) {
						radioGroups.get(r.getLabel()).add(radioNode);
					}
					// Marked as removed, so remove for next start
					else if (r.isRemoved()) {
						RadioHandler.getInstance().removeRadio(r);
					} else {
						DefaultMutableTreeNode labelNode;
						if (r.getLabel() == null || r.getLabel().trim().equals("")) {
							//labelNode = new DefaultMutableTreeNode(LanguageTool.getString("UNLABELED"));
							radioGroupNoLabel.put(r.getName(), radioNode);
						} else {
							if (!r.isRemoved()) {
								labelNode = new DefaultMutableTreeNode(r.getLabel());
								labelNode.add(radioNode);
								radioGroups.put(r.getLabel(), labelNode);
							}
						}
					}
				}
			}
		}

		// Add label nodes
		for (DefaultMutableTreeNode labelNode : radioGroups.values()) {
			root.add(labelNode);
		}
		// Add radio nodes without labels
		for (DefaultMutableTreeNode radioNode : radioGroupNoLabel.values()) {
			root.add(radioNode);
		}
	}

	/**
	 * Refresh.
	 * 
	 * @param radios
	 *            the radios
	 * @param presetRadios
	 *            the preset radios
	 * @param treeModel
	 *            the tree model
	 * @param currentFilter
	 *            the current filter
	 * @param showAllStations
	 *            the show all stations
	 */
	public static void refresh(List<Radio> radios, List<Radio> presetRadios, DefaultTreeModel treeModel, String currentFilter, boolean showAllStations) {
		DefaultMutableTreeNode root = (DefaultMutableTreeNode) treeModel.getRoot();
		root.setUserObject(LanguageTool.getString("RADIO"));
		root.removeAllChildren();
		addRadioNodes(radios, presetRadios, root, currentFilter, showAllStations);
		treeModel.reload();
	}
}
